pub struct AffidavitWindow<T: Config> {
pub start: BlockNumberFor<T>,
pub end: BlockNumberFor<T>,
}Expand description
Represents the affidavit submission window for the current session.
Defines the inclusive block range during which authors are permitted to submit affidavits for the next upcoming session.
Semantics
start: First block at which affidavit submission is allowed.end: Last block (inclusive) after which submissions are rejected. Affidavit Window for the current session
Fields
start: BlockNumberFor<T>Block number at which affidavit submission begins.
end: BlockNumberFor<T>Block number at which affidavit submission ends.