pub struct ElectionWindow<T: Config> {
pub start: BlockNumberFor<T>,
pub end: BlockNumberFor<T>,
}Expand description
Represents the election execution window for the current session.
Defines the block range during which election logic is expected to be executed for determining the next session’s validator set.
Semantics
start: First block at which election execution may begin.end: Final block for election execution.
Fields
start: BlockNumberFor<T>Block number at which election execution begins.
end: BlockNumberFor<T>Block number at which election execution ends.