pub type AssetOf<T> = <<T as Config>::RoleAdapter as RoleManager<AuthorOf<T>>>::Asset;Expand description
The asset type associated with an author-role.
Used for funding, collateral, rewarding or penalizing authors and backers.
pub type AssetOf<T> = <<T as Config>::RoleAdapter as RoleManager<AuthorOf<T>>>::Asset;The asset type associated with an author-role.
Used for funding, collateral, rewarding or penalizing authors and backers.