pub type AuthorOf<T> = <T as Config>::AccountId;Expand description
The AccountId type representing an author in this runtime.
Acts as the primary key for tracking points, rewards, penalties, and election data.
pub type AuthorOf<T> = <T as Config>::AccountId;The AccountId type representing an author in this runtime.
Acts as the primary key for tracking points, rewards, penalties, and election data.