pub type AuthorTimeStampOf<T> = <<T as Config>::RoleAdapter as RoleManager<AuthorOf<T>>>::TimeStamp;Expand description
Timestamp associated with an author role for various operations such as deffered rewards and penalities
pub type AuthorTimeStampOf<T> = <<T as Config>::RoleAdapter as RoleManager<AuthorOf<T>>>::TimeStamp;Timestamp associated with an author role for various operations such as deffered rewards and penalities