pub type ElectionParams<T> = <<T as Config>::ElectionAdapter as ElectionManager<AuthorOf<T>>>::Params;Expand description
Parameters for configuring an election i.e, the input authors and their corresponding election weight.
pub type ElectionParams<T> = <<T as Config>::ElectionAdapter as ElectionManager<AuthorOf<T>>>::Params;Parameters for configuring an election i.e, the input authors and their corresponding election weight.