pub type OffenceReporter<T> = <T as Config>::AccountId;Expand description
Type alias representing the reporting account that detected the offence.
pub type OffenceReporter<T> = <T as Config>::AccountId;Type alias representing the reporting account that detected the offence.