Type Alias SessionId

pub type SessionId<T> = <T as Config>::ValidatorId;
Type alias for the Validator ID used by [pallet_session].

In the context of elections, candidate authors are mapped to this type to interact with the session pallet (e.g., for validator set queries or election participation).