pub type ActualAsset<T> = <<T as Config>::Asset as Inspect<AuthorOf<T>>>::Balance;Expand description
The concrete fungible balance type of the asset associated with an author.
Represents the fungible units that can be rewarded, or penalized.
This is ensured to be AssetOf where AssetOf == ActualAsset enforced
via Config::Asset