pub type BackerOf<T> = <<T as Config>::RoleAdapter as FundRoles<AuthorOf<T>>>::Backer;Expand description
Type representing an entity or account backing an author, as managed by FundRoles.
- Typically used to track external funding, sponsorship, or support for authors.
- Allows pallets to query or interact with the backing source of an author.