pub type ElectionElects<T> = <<T as Config>::ElectionAdapter as ElectionManager<AuthorOf<T>>>::Elected;Expand description
Set of authors successfully elected by the author-role election module.
- Can be iterated over to assign points, rewards, or responsibilities.
- Typically used to determine which authors are active for a reward cycle or session.